`data.csv` is a Q/A dataset scraped from Substack's FAQ here:  https://support.substack.com/hc/en-us/categories/360002411231-General

`train.ipynb` to create a knowledge base of Substack's support tickets.

`test.ipynb` to run the pipeline that answers Substack's support tickets using the knowledge base.

`app.py` to run the streamlit app that is test.py
